package com.huiju.estateagents.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.*;
import com.huiju.estateagents.excel.ShareChildRecordExport;
import com.huiju.estateagents.mapper.TaPersonMapper;
import com.huiju.estateagents.mapper.TaShareActivityMapper;
import com.huiju.estateagents.mapper.TaShareChildRecordMapper;
import com.huiju.estateagents.mapper.TaShareRecordMapper;
import com.huiju.estateagents.service.ITaShareChildRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 *   服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@Service
public class TaShareChildRecordServiceImpl extends ServiceImpl<TaShareChildRecordMapper, TaShareChildRecord> implements ITaShareChildRecordService {

    @Autowired
    private TaShareChildRecordMapper taShareChildRecordMapper;
    @Autowired
    private TaPersonMapper taPersonMapper;
    @Autowired
    private TaShareActivityMapper activityMapper;
    @Autowired
    private TaShareRecordMapper tashareRecordmapper;

    @Override
    public IPage<TaShareChildRecord> getList(Integer pageNum, Integer pageSize, Integer groupActivityId, Integer status, Integer recordId, Integer orgId) {
        IPage<TaShareChildRecord> page = new Page<>(pageNum,pageSize);
        return taShareChildRecordMapper.getList(page, groupActivityId, status, recordId, orgId);
    }

    @Override
    public ResponseBean validateRule(TaShareChildRecord taShareChildRecord) {
        ResponseBean responseBean = new ResponseBean();
        try{
            TaPerson taPerson = taPersonMapper.getById(taShareChildRecord.getPersonId());
            TaShareActivity taShareActivity = activityMapper.selectTaShareActivityById(taShareChildRecord.getGroupActivityId());

            if (taPerson.getPoints() == null || taPerson.getPoints() < taShareActivity.getIntegral()){
                responseBean.addError("积分不足");
                return responseBean;
            }
            //判断参团人数是否已满
            if (taShareActivity.getGroupBuyPeople().equals(taShareActivity.getJoinPeople())){
                TaShareRecord taShareRecord = new TaShareRecord();
                taShareRecord.setStatus(0);
                taShareRecord.setRecordId(taShareChildRecord.getRecordId());
                tashareRecordmapper.updateById(taShareRecord);
                responseBean.addError("拼团已结束");
                return responseBean;
            }
            //扣取积分,更新参团人数
            taPerson.setPoints(taPerson.getPoints() - taShareActivity.getIntegral());
            taPersonMapper.updateById(taPerson);
            activityMapper.updateJoinPeople(taShareChildRecord.getGroupActivityId());
            responseBean.addSuccess("您已成功参团");

        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError("参团失败");
        }

        return responseBean;
    }

    @Override
    public Integer getShareRecord(Integer recordId, Integer status) {
        QueryWrapper<TaShareChildRecord> taShareChildRecordQueryWrapper= new QueryWrapper<>();
        taShareChildRecordQueryWrapper.eq("record_id",recordId);
        taShareChildRecordQueryWrapper.eq("status",status);
        return taShareChildRecordMapper.selectCount(taShareChildRecordQueryWrapper);
    }

    @Override
    public List<ShareChildRecordExport> getShareRecordExportList(Integer pageCode, Integer pageSize, Integer recordId, Integer status, Integer groupActivityId) {
        List<ShareChildRecordExport> list= taShareChildRecordMapper.getShareRecordExportList(pageCode ,pageSize, recordId, status, groupActivityId);
        return list;
    }
}
